# Table of Contents

- [workspace-setup-for-self-built-software-discovery](<./workspace-setup-for-self-built-software-discovery.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Workspace Setup for Self-Built Software Discovery](<./Workspace-Setup-for-Self-Built-Software-Discovery.md>)
  - [Introduction](<./Workspace-Setup-for-Self-Built-Software-Discovery/Introduction.md>)
  - [Provisioning and Configuration](<./Workspace-Setup-for-Self-Built-Software-Discovery/Provisioning-and-Configuration.md>)
  - [Customizing Relations](<./Workspace-Setup-for-Self-Built-Software-Discovery/Customizing-Relations.md>)
  - [Enabling Tech Stack Discovery](<./Workspace-Setup-for-Self-Built-Software-Discovery/Enabling-Tech-Stack-Discovery.md>)
  - [Meta Model Extension](<./Workspace-Setup-for-Self-Built-Software-Discovery/Meta-Model-Extension.md>)
